==> huaweicloudsdknlp-3.0.77-py2.py3-none-any.whl: huaweicloudsdknlp/v2/model/run_sentence_embedding_request.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class RunSentenceEmbeddingRequest:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'body': 'PostSentenceEmbeddingReq'
    }

    attribute_map = {
        'body': 'body'
    }

    def __init__(self, body=None):
        """RunSentenceEmbeddingRequest - a model defined in huaweicloud sdk"""
        
        

        self._body = None
        self.discriminator = None

        if body is not None:
            self.body = body

    @property
    def body(self):
        """Gets the body of this RunSentenceEmbeddingRequest.


        :return: The body of this RunSentenceEmbeddingRequest.
        :rtype: PostSentenceEmbeddingReq
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this RunSentenceEmbeddingRequest.


        :param body: The body of this RunSentenceEmbeddingRequest.
        :type: PostSentenceEmbeddingReq
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RunSentenceEmbeddingRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdknlp-3.0.90-py2.py3-none-any.whl: huaweicloudsdknlp/v2/model/run_sentence_embedding_request.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class RunSentenceEmbeddingRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'body': 'PostSentenceEmbeddingReq'
    }

    attribute_map = {
        'body': 'body'
    }

    def __init__(self, body=None):
        """RunSentenceEmbeddingRequest

        The model defined in huaweicloud sdk

        :param body: Body of the RunSentenceEmbeddingRequest
        :type body: :class:`huaweicloudsdknlp.v2.PostSentenceEmbeddingReq`
        """
        
        

        self._body = None
        self.discriminator = None

        if body is not None:
            self.body = body

    @property
    def body(self):
        """Gets the body of this RunSentenceEmbeddingRequest.


        :return: The body of this RunSentenceEmbeddingRequest.
        :rtype: :class:`huaweicloudsdknlp.v2.PostSentenceEmbeddingReq`
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this RunSentenceEmbeddingRequest.


        :param body: The body of this RunSentenceEmbeddingRequest.
        :type body: :class:`huaweicloudsdknlp.v2.PostSentenceEmbeddingReq`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RunSentenceEmbeddingRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
